@@ -391,6 +391,15 @@ class TestTreeFromDict:
             "/set3",
         ]
 
+    def test_datatree_values(self):
+        dat1 = DataTree(data=xr.Dataset({"a": 1}))
+        expected = DataTree()
+        expected["a"] = dat1
+
+        actual = DataTree.from_dict({"a": dat1})
+
+        dtt.assert_identical(actual, expected)
+
     def test_roundtrip(self, simple_datatree):
         dt = simple_datatree
         roundtrip = DataTree.from_dict(dt.to_dict())
@@ -448,3 +457,35 @@ class TestDatasetView:
 
 class TestRestructuring:
     ...
+
+
+class TestPipe:
+    def test_noop(self, create_test_datatree):
+        dt = create_test_datatree()
+
+        actual = dt.pipe(lambda tree: tree)
+        assert actual.identical(dt)
+
+    def test_params(self, create_test_datatree):
+        dt = create_test_datatree()
+
+        def f(tree, **attrs):
+            return tree.assign(arr_with_attrs=xr.Variable("dim0", [], attrs=attrs))
+
+        attrs = {"x": 1, "y": 2, "z": 3}
+
+        actual = dt.pipe(f, **attrs)
+        assert actual["arr_with_attrs"].attrs == attrs
+
+    def test_named_self(self, create_test_datatree):
+        dt = create_test_datatree()
+
+        def f(x, tree, y):
+            tree.attrs.update({"x": x, "y": y})
+            return tree
+
+        attrs = {"x": 1, "y": 2}
+
+        actual = dt.pipe((f, "tree"), **attrs)
+
+        assert actual is dt and actual.attrs == attrs
